CgroupArray

Struct CgroupArray 

pub struct CgroupArray<T> { /* private fields */ }
An array of cgroups.

eBPF programs can test whether a packet or the current task belongs to a cgroup by calling bpf_skb_under_cgroup or bpf_current_task_under_cgroup against this map. You populate it from userspace with the file descriptors of cgroup directories.

Minimum kernel version

The minimum kernel version required to use this feature is 4.8.

Examples

use aya::maps::CgroupArray;

let mut array = CgroupArray::try_from(bpf.map_mut("CGROUPS").unwrap())?;
// cgroup_fd is the RawFd of an open cgroup directory.
array.set(0, cgroup_fd, 0);

Implementations

Source

impl<T: Borrow<MapData>> CgroupArray<T>

pub fn len(&self) -> u32

Returns the number of elements in the array.

This corresponds to the value of bpf_map_def::max_entries on the eBPF side.

Source

impl<T: BorrowMut<MapData>> CgroupArray<T>

pub fn set( &mut self, index: u32, cgroup_fd: impl AsRawFd, flags: u64, ) -> Result<(), MapError>

Stores a cgroup file descriptor at the given index.

Errors

Returns MapError::OutOfBounds if index is out of bounds, MapError::SyscallError if bpf_map_update_elem fails.

pub fn unset(&mut self, index: u32) -> Result<(), MapError>

Un-sets the cgroup at the given index.

Errors

Returns MapError::OutOfBounds if index is out of bounds, MapError::SyscallError if bpf_map_delete_elem fails.

Source

impl<T: Borrow<MapData>> CgroupArray<T>

pub fn pin<P: AsRef<Path>>(self, path: P) -> Result<(), PinError>

Pins the map to a BPF filesystem.

When a map is pinned it will remain loaded until the corresponding file is deleted. All parent directories in the given path must already exist.