HashMap

Struct HashMap 

pub struct HashMap<T, K, V> { /* private fields */ }
A hash map that can be shared between eBPF programs and user space.

Minimum kernel version

The minimum kernel version required to use this feature is 3.19.

Examples

use aya::maps::HashMap;

let mut redirect_ports = HashMap::try_from(bpf.map_mut("REDIRECT_PORTS").unwrap())?;

// redirect port 80 to 8080
redirect_ports.insert(80, 8080, 0);
// redirect port 443 to 8443
redirect_ports.insert(443, 8443, 0);

Implementations

Source

impl<T: Borrow<MapData>, K: Pod, V: Pod> HashMap<T, K, V>

pub fn get(&self, key: &K, flags: u64) -> Result<V, MapError>

Returns a copy of the value associated with the key.

pub fn iter(&self) -> MapIter<'_, K, V, Self>

An iterator visiting all key-value pairs in arbitrary order. The iterator item type is Result<(K, V), MapError>.

pub fn keys(&self) -> MapKeys<'_, K>

An iterator visiting all keys in arbitrary order. The iterator element type is Result<K, MapError>.

Source

impl<T: BorrowMut<MapData>, K: Pod, V: Pod> HashMap<T, K, V>

pub fn insert( &mut self, key: impl Borrow<K>, value: impl Borrow<V>, flags: u64, ) -> Result<(), MapError>

Inserts a key-value pair into the map.

pub fn remove(&mut self, key: &K) -> Result<(), MapError>

Removes a key from the map.

Source

impl<T: Borrow<MapData>, K: Pod, V: Pod> HashMap<T, K, V>

pub fn pin<P: AsRef<Path>>(self, path: P) -> Result<(), PinError>

Pins the map to a BPF filesystem.

When a map is pinned it will remain loaded until the corresponding file is deleted. All parent directories in the given path must already exist.

Source

impl<K: Pod, V: Pod> HashMap<MapData, K, V>

pub fn create(max_entries: u32, flags: u32) -> Result<Self, MapError>

Creates a standalone map with the given max_entries capacity and flags.