Queue

Struct Queue 

pub struct Queue<T, V: Pod> { /* private fields */ }
A FIFO queue.

Minimum kernel version

The minimum kernel version required to use this feature is 4.20.

Examples

use aya::maps::Queue;

let mut queue = Queue::try_from(bpf.map_mut("ARRAY").unwrap())?;
queue.push(42, 0)?;
queue.push(43, 0)?;
assert_eq!(queue.pop(0)?, 42);

Implementations

Source

impl<T: Borrow<MapData>, V: Pod> Queue<T, V>

pub fn capacity(&self) -> u32

Returns the number of elements the queue can hold.

This corresponds to the value of bpf_map_def::max_entries on the eBPF side.

Source

impl<T: BorrowMut<MapData>, V: Pod> Queue<T, V>

pub fn pop(&mut self, flags: u64) -> Result<V, MapError>

Removes the first element and returns it.

Errors

Returns MapError::ElementNotFound if the queue is empty, MapError::SyscallError if bpf_map_lookup_and_delete_elem fails.

pub fn push( &mut self, value: impl Borrow<V>, flags: u64, ) -> Result<(), MapError>

Appends an element at the end of the queue.

Errors

MapError::SyscallError if bpf_map_update_elem fails.

Source

impl<T: Borrow<MapData>, V: Pod> Queue<T, V>

pub fn pin<P: AsRef<Path>>(self, path: P) -> Result<(), PinError>

Pins the map to a BPF filesystem.

When a map is pinned it will remain loaded until the corresponding file is deleted. All parent directories in the given path must already exist.

Source

impl<V: Pod> Queue<MapData, V>

pub fn create(max_entries: u32, flags: u32) -> Result<Self, MapError>

Creates a standalone map with the given max_entries capacity and flags.