pub struct CgroupSysctl { /* private fields */ }Expand description
A program used to watch for sysctl changes.
CgroupSysctl programs can be attached to a cgroup and will be called every
time a process inside that cgroup tries to read from or write to a sysctl knob in proc.
Minimum kernel version
The minimum kernel version required to use this feature is 5.2.
Examples
use std::fs::File;
use aya::programs::{CgroupAttachMode, CgroupSysctl};
let file = File::open("/sys/fs/cgroup/unified")?;
let program: &mut CgroupSysctl = bpf.program_mut("cgroup_sysctl").unwrap().try_into()?;
program.load()?;
program.attach(file, CgroupAttachMode::Single)?;Implementations
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub const PROGRAM_TYPE: ProgramType = ProgramType::CgroupSysctl
pub const PROGRAM_TYPE: ProgramType = ProgramType::CgroupSysctl
The type of the program according to the kernel.
Sourcepub fn load(&mut self) -> Result<(), ProgramError>
pub fn load(&mut self) -> Result<(), ProgramError>
Loads the program inside the kernel.
Sourcepub fn attach<T: AsFd>(
&mut self,
cgroup: T,
mode: CgroupAttachMode,
) -> Result<CgroupSysctlLinkId, ProgramError>
pub fn attach<T: AsFd>( &mut self, cgroup: T, mode: CgroupAttachMode, ) -> Result<CgroupSysctlLinkId, ProgramError>
Attaches the program to the given cgroup.
The returned value can be used to detach, see CgroupSysctl::detach.
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub fn detach(
&mut self,
link_id: CgroupSysctlLinkId,
) -> Result<(), ProgramError>
pub fn detach( &mut self, link_id: CgroupSysctlLinkId, ) -> Result<(), ProgramError>
Detaches the program.
See Self::attach.
Sourcepub fn take_link(
&mut self,
link_id: CgroupSysctlLinkId,
) -> Result<CgroupSysctlLink, ProgramError>
pub fn take_link( &mut self, link_id: CgroupSysctlLinkId, ) -> Result<CgroupSysctlLink, ProgramError>
Takes ownership of the link referenced by the provided link_id.
The caller takes the responsibility of managing the lifetime of the link. When the
returned
CgroupSysctlLink
is dropped, the link will be detached.
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub fn unload(&mut self) -> Result<(), ProgramError>
pub fn unload(&mut self) -> Result<(), ProgramError>
Unloads the program from the kernel.
Tracked links will be detached before unloading the program.
Attachment mechanisms that do not create tracked links are
not affected. Note that owned links obtained using
take_link() will not be detached.
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub fn fd(&self) -> Result<&ProgramFd, ProgramError>
pub fn fd(&self) -> Result<&ProgramFd, ProgramError>
Returns the file descriptor of this Program.
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub fn pin<P: AsRef<Path>>(&mut self, path: P) -> Result<(), PinError>
pub fn pin<P: AsRef<Path>>(&mut self, path: P) -> Result<(), PinError>
Pins the program to a BPF filesystem.
When a BPF object is pinned to a BPF filesystem it will remain loaded after Aya has unloaded the program. To remove the program, the file on the BPF filesystem must be removed. Any directories in the the path provided should have been created by the caller.
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub fn from_pin<P: AsRef<Path>>(path: P) -> Result<Self, ProgramError>
pub fn from_pin<P: AsRef<Path>>(path: P) -> Result<Self, ProgramError>
Creates a program from a pinned entry on a bpffs.
Existing links will not be populated. To work with existing links you should use crate::programs::links::PinnedLink.
On drop, any managed links are detached and the program is unloaded. This will not result in the program being unloaded from the kernel if it is still pinned.
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub fn from_program_info(
info: ProgramInfo,
name: Cow<'static, str>,
) -> Result<Self, ProgramError>
pub fn from_program_info( info: ProgramInfo, name: Cow<'static, str>, ) -> Result<Self, ProgramError>
Constructs an instance of a Self from a ProgramInfo.
This allows the caller to get a handle to an already loaded program from the kernel without having to load it again.
Errors
- If the program type reported by the kernel does not match
Self::PROGRAM_TYPE. - If the file descriptor of the program cannot be cloned.
Sourceimpl CgroupSysctl
impl CgroupSysctl
Sourcepub fn info(&self) -> Result<ProgramInfo, ProgramError>
pub fn info(&self) -> Result<ProgramInfo, ProgramError>
Returns metadata information of this program.
Uses kernel v4.13 features.