pub struct TestRunOptions<'a> {
pub data_in: Option<&'a [u8]>,
pub data_out: Option<&'a mut [u8]>,
pub ctx_in: Option<&'a [u8]>,
pub ctx_out: Option<&'a mut [u8]>,
pub repeat: u32,
pub attrs: TestRunAttrs,
}Expand description
Options for running a BPF program test.
See kernel doc and ebpf.io for detailed usage.
Fields
data_in: Option<&'a [u8]>Input packet data to pass to the program.
data_out: Option<&'a mut [u8]>Output buffer for packet data modified by the program.
ctx_in: Option<&'a [u8]>Input context to pass to the program.
ctx_out: Option<&'a mut [u8]>Output buffer for context written back by the program.
repeat: u32Number of times to repeat the test. Defaults to 1.
attrs: TestRunAttrsKernel execution attributes (XDP batch size).
Implementations
Sourceimpl TestRunOptions<'_>
impl TestRunOptions<'_>